from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelCall:
	"""SelCall commands group definition. 7 total commands, 2 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("selCall", core, parent)

	@property
	def userDefined(self):
		"""userDefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_userDefined'):
			from .SelCall_.UserDefined import UserDefined
			self._userDefined = UserDefined(self._core, self._base)
		return self._userDefined

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .SelCall_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	def get_cfgenerator(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:CFGenerator \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.tones.selCall.get_cfgenerator() \n
		Couples the SelCall tone settings of the analyzer to the corresponding generator settings. \n
			:return: conf_from_gen: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:CFGenerator?')
		return Conversions.str_to_bool(response)

	def set_cfgenerator(self, conf_from_gen: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:CFGenerator \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.selCall.set_cfgenerator(conf_from_gen = False) \n
		Couples the SelCall tone settings of the analyzer to the corresponding generator settings. \n
			:param conf_from_gen: OFF | ON
		"""
		param = Conversions.bool_to_str(conf_from_gen)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:CFGenerator {param}')

	def get_slength(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:SLENgth \n
		Snippet: value: int = driver.configure.afRf.measurement.multiEval.tones.selCall.get_slength() \n
		Specifies the expected length of the analyzed SelCall tone sequence (number of digits) . By default, the user-defined
		tone definition is disabled, and the length is fixed (five digits) . If the user-defined tone definition is enabled, you
		can configure the length. \n
			:return: seq_length: Range: 2 to 42
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, seq_length: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:SLENgth \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.selCall.set_slength(seq_length = 1) \n
		Specifies the expected length of the analyzed SelCall tone sequence (number of digits) . By default, the user-defined
		tone definition is disabled, and the length is fixed (five digits) . If the user-defined tone definition is enabled, you
		can configure the length. \n
			:param seq_length: Range: 2 to 42
		"""
		param = Conversions.decimal_value_to_str(seq_length)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:SLENgth {param}')

	# noinspection PyTypeChecker
	def get_standard(self) -> enums.SelCallStandard:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:STANdard \n
		Snippet: value: enums.SelCallStandard = driver.configure.afRf.measurement.multiEval.tones.selCall.get_standard() \n
		Selects a selective-calling standard for SelCall tone sequence analysis. \n
			:return: sel_call_standard: CCIR | EEA | EIA | ZVEI1 | ZVEI2 | ZVEI3 | DZVei | PZVei
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:STANdard?')
		return Conversions.str_to_scalar_enum(response, enums.SelCallStandard)

	def set_standard(self, sel_call_standard: enums.SelCallStandard) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:STANdard \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.selCall.set_standard(sel_call_standard = enums.SelCallStandard.CCIR) \n
		Selects a selective-calling standard for SelCall tone sequence analysis. \n
			:param sel_call_standard: CCIR | EEA | EIA | ZVEI1 | ZVEI2 | ZVEI3 | DZVei | PZVei
		"""
		param = Conversions.enum_scalar_to_str(sel_call_standard, enums.SelCallStandard)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:STANdard {param}')

	# noinspection PyTypeChecker
	def get_maccuracy(self) -> enums.MeasAccuracy:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:MACCuracy \n
		Snippet: value: enums.MeasAccuracy = driver.configure.afRf.measurement.multiEval.tones.selCall.get_maccuracy() \n
		Configures the accuracy of the analysis of SelCall tone sequences. \n
			:return: meas_accuracy: NORMal | HIGH NORMal: lower tone detection accuracy / minimum pause length HIGH: higher tone detection accuracy / minimum pause length
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:MACCuracy?')
		return Conversions.str_to_scalar_enum(response, enums.MeasAccuracy)

	def set_maccuracy(self, meas_accuracy: enums.MeasAccuracy) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:MACCuracy \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.selCall.set_maccuracy(meas_accuracy = enums.MeasAccuracy.HIGH) \n
		Configures the accuracy of the analysis of SelCall tone sequences. \n
			:param meas_accuracy: NORMal | HIGH NORMal: lower tone detection accuracy / minimum pause length HIGH: higher tone detection accuracy / minimum pause length
		"""
		param = Conversions.enum_scalar_to_str(meas_accuracy, enums.MeasAccuracy)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SELCall:MACCuracy {param}')

	def clone(self) -> 'SelCall':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SelCall(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pocsag:
	"""Pocsag commands group definition. 8 total commands, 0 Sub-groups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pocsag", core, parent)

	def get_standard_dev(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:SDEViation \n
		Snippet: value: List[float] = driver.source.afRf.generator.pocsag.get_standard_dev() \n
		Configures the frequency deviations used for 2FSK modulation, for POCSAG. The values apply if inverted modulation is
		disabled. A query returns <DeviationS0>, <DeviationS1>. \n
			:return: sdeviation: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list_with_opc('SOURce:AFRF:GENerator<Instance>:POCSag:SDEViation?')
		return response

	def set_standard_dev(self, sdeviation: List[float]) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:SDEViation \n
		Snippet: driver.source.afRf.generator.pocsag.set_standard_dev(sdeviation = [1.1, 2.2, 3.3]) \n
		Configures the frequency deviations used for 2FSK modulation, for POCSAG. The values apply if inverted modulation is
		disabled. A query returns <DeviationS0>, <DeviationS1>. \n
			:param sdeviation: No help available
		"""
		param = Conversions.list_to_csv_str(sdeviation)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:POCSag:SDEViation {param}')

	def get_imodulation(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:IMODulation \n
		Snippet: value: bool = driver.source.afRf.generator.pocsag.get_imodulation() \n
		Enables inverted modulation (symbol 0 negative deviation, symbol 1 positive deviation) , for POCSAG. \n
			:return: imod: OFF | ON
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:POCSag:IMODulation?')
		return Conversions.str_to_bool(response)

	def set_imodulation(self, imod: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:IMODulation \n
		Snippet: driver.source.afRf.generator.pocsag.set_imodulation(imod = False) \n
		Enables inverted modulation (symbol 0 negative deviation, symbol 1 positive deviation) , for POCSAG. \n
			:param imod: OFF | ON
		"""
		param = Conversions.bool_to_str(imod)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:POCSag:IMODulation {param}')

	def get_symbol_rate(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:SRATe \n
		Snippet: value: int = driver.source.afRf.generator.pocsag.get_symbol_rate() \n
		Configures the symbol rate for POCSAG. \n
			:return: srate: Range: 0 symbol/s to 5000 symbol/s, Unit: symbol/s
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:POCSag:SRATe?')
		return Conversions.str_to_int(response)

	def set_symbol_rate(self, srate: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:SRATe \n
		Snippet: driver.source.afRf.generator.pocsag.set_symbol_rate(srate = 1) \n
		Configures the symbol rate for POCSAG. \n
			:param srate: Range: 0 symbol/s to 5000 symbol/s, Unit: symbol/s
		"""
		param = Conversions.decimal_value_to_str(srate)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:POCSag:SRATe {param}')

	def get_paddress(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:PADDress \n
		Snippet: value: int = driver.source.afRf.generator.pocsag.get_paddress() \n
		Configures the pager address to which a POCSAG transmission is sent. \n
			:return: paddress: Range: 0 to 2097151
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:POCSag:PADDress?')
		return Conversions.str_to_int(response)

	def set_paddress(self, paddress: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:PADDress \n
		Snippet: driver.source.afRf.generator.pocsag.set_paddress(paddress = 1) \n
		Configures the pager address to which a POCSAG transmission is sent. \n
			:param paddress: Range: 0 to 2097151
		"""
		param = Conversions.decimal_value_to_str(paddress)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:POCSag:PADDress {param}')

	def get_fbits(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:FBITs \n
		Snippet: value: str = driver.source.afRf.generator.pocsag.get_fbits() \n
		Configures the function bits for POCSAG. \n
			:return: fbits: Range: #B0 to #B11
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:POCSag:FBITs?')
		return trim_str_response(response)

	def set_fbits(self, fbits: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:FBITs \n
		Snippet: driver.source.afRf.generator.pocsag.set_fbits(fbits = r1) \n
		Configures the function bits for POCSAG. \n
			:param fbits: Range: #B0 to #B11
		"""
		param = Conversions.value_to_str(fbits)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:POCSag:FBITs {param}')

	# noinspection PyTypeChecker
	def get_ptype(self) -> enums.PagerType:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:PTYPe \n
		Snippet: value: enums.PagerType = driver.source.afRf.generator.pocsag.get_ptype() \n
		Specifies whether a message is transmitted to the DUT and which message format is used, for POCSAG. \n
			:return: pager_type: NUMeric | ALPHanumeric | TONLy NUMeric: message in numeric format ALPHanumeric: message in alpha-numeric format TONLy: no message
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:POCSag:PTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.PagerType)

	def set_ptype(self, pager_type: enums.PagerType) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:PTYPe \n
		Snippet: driver.source.afRf.generator.pocsag.set_ptype(pager_type = enums.PagerType.ALPHanumeric) \n
		Specifies whether a message is transmitted to the DUT and which message format is used, for POCSAG. \n
			:param pager_type: NUMeric | ALPHanumeric | TONLy NUMeric: message in numeric format ALPHanumeric: message in alpha-numeric format TONLy: no message
		"""
		param = Conversions.enum_scalar_to_str(pager_type, enums.PagerType)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:POCSag:PTYPe {param}')

	def get_message(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:MESSage \n
		Snippet: value: str = driver.source.afRf.generator.pocsag.get_message() \n
		Specifies a character sequence for numeric and alphanumeric messages, for POCSAG. \n
			:return: content: Message as string
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:POCSag:MESSage?')
		return trim_str_response(response)

	def set_message(self, content: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:MESSage \n
		Snippet: driver.source.afRf.generator.pocsag.set_message(content = '1') \n
		Specifies a character sequence for numeric and alphanumeric messages, for POCSAG. \n
			:param content: Message as string
		"""
		param = Conversions.value_to_quoted_str(content)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:POCSag:MESSage {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FskMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:POCSag:MODE \n
		Snippet: value: enums.FskMode = driver.source.afRf.generator.pocsag.get_mode() \n
		Queries the modulation type used for POCSAG. \n
			:return: mode: FSK2
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:POCSag:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FskMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sip:
	"""Sip commands group definition. 6 total commands, 0 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sip", core, parent)

	def get_response(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RESPonse \n
		Snippet: value: str = driver.source.afRf.generator.voip.sip.get_response() \n
		Queries the text of the last received SIP response. \n
			:return: sip_response: Response string, for example 'OK'
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RESPonse?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_state(self) -> enums.SipState:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:SIP:STATe \n
		Snippet: value: enums.SipState = driver.source.afRf.generator.voip.sip.get_state() \n
		Queries the state of the VoIP connection to the DUT. \n
			:return: sip_state: TERMinated | ESTablished | ERRor
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:SIP:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.SipState)

	def get_code(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:SIP:CODE \n
		Snippet: value: int = driver.source.afRf.generator.voip.sip.get_code() \n
		Queries the code number of the last received SIP response. \n
			:return: sip_code: Decimal number, for example 200
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:SIP:CODE?')
		return Conversions.str_to_int(response)

	def get_rprotocol(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RPRotocol \n
		Snippet: value: str = driver.source.afRf.generator.voip.sip.get_rprotocol() \n
		No command help available \n
			:return: protocol: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RPRotocol?')
		return trim_str_response(response)

	def get_rcause(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RCAuse \n
		Snippet: value: str = driver.source.afRf.generator.voip.sip.get_rcause() \n
		No command help available \n
			:return: rcause: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RCAuse?')
		return trim_str_response(response)

	def get_rt_ext(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RTEXt \n
		Snippet: value: str = driver.source.afRf.generator.voip.sip.get_rt_ext() \n
		No command help available \n
			:return: rt_ext: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:SIP:RTEXt?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MultiTone:
	"""MultiTone commands group definition. 9 total commands, 7 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("multiTone", core, parent)

	@property
	def tone(self):
		"""tone commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tone'):
			from .MultiTone_.Tone import Tone
			self._tone = Tone(self._core, self._base)
		return self._tone

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .MultiTone_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	@property
	def crest(self):
		"""crest commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_crest'):
			from .MultiTone_.Crest import Crest
			self._crest = Crest(self._core, self._base)
		return self._crest

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .MultiTone_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .MultiTone_.Level import Level
			self._level = Level(self._core, self._base)
		return self._level

	@property
	def ilevel(self):
		"""ilevel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ilevel'):
			from .MultiTone_.Ilevel import Ilevel
			self._ilevel = Ilevel(self._core, self._base)
		return self._ilevel

	@property
	def tlevel(self):
		"""tlevel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tlevel'):
			from .MultiTone_.Tlevel import Tlevel
			self._tlevel = Tlevel(self._core, self._base)
		return self._tlevel

	def clone(self) -> 'MultiTone':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MultiTone(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tetra:
	"""Tetra commands group definition. 4 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tetra", core, parent)

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .Tetra_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	def get_symbol_rate(self) -> int:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:TETRa:SRATe \n
		Snippet: value: int = driver.configure.vse.measurement.tetra.get_symbol_rate() \n
		No command help available \n
			:return: symbol_rate: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:TETRa:SRATe?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_demodulation(self) -> enums.DemodulationType:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:TETRa:DEModulation \n
		Snippet: value: enums.DemodulationType = driver.configure.vse.measurement.tetra.get_demodulation() \n
		No command help available \n
			:return: demodulation_type: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:TETRa:DEModulation?')
		return Conversions.str_to_scalar_enum(response, enums.DemodulationType)

	def clone(self) -> 'Tetra':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tetra(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 4 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	@property
	def trace(self):
		"""trace commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_trace'):
			from .Frequency_.Trace import Trace
			self._trace = Trace(self._core, self._base)
		return self._trace

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Lower_Freq: float: Range: 100 kHz to 3 GHz, Unit: Hz
			- Higher_Freq: float: Range: 100 kHz to 3 GHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Lower_Freq'),
			ArgStruct.scalar_float('Higher_Freq')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Lower_Freq: float = None
			self.Higher_Freq: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:FREQuency \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rifBandwidth.frequency.fetch() \n
		Fetches the lower and higher RF frequencies left and right from the nominal frequency at which the noise has increased to
		the noise target value (noise level method) or the SINAD audio signal quality has dropped down to the target value
		(TIA-603-D method) . \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:FREQuency?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:FREQuency \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rifBandwidth.frequency.read() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:FREQuency?', self.__class__.ResultData())

	def clone(self) -> 'Frequency':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frequency(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Specific:
	"""Specific commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("specific", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Date: str: Date of the calibration as string
			- Time: str: Time of the calibration as string"""
		__meta_args_list = [
			ArgStruct.scalar_str('Date'),
			ArgStruct.scalar_str('Time')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Date: str = None
			self.Time: str = None

	def get(self, mode: enums.CalibType) -> GetStruct:
		"""SCPI: CALibration:BASE:LATest:SPECific \n
		Snippet: value: GetStruct = driver.calibration.base.latest.specific.get(mode = enums.CalibType.CALibration) \n
		Queries date and time of the latest calibration of the specified type. \n
			:param mode: FSCorrection | CALibration | OGCal Type of the calibration for which information is queried FSCorrection Correction performed in factory or service CALibration Verification in the factory OGCal Verification by the service (outgoing calibration)
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = Conversions.enum_scalar_to_str(mode, enums.CalibType)
		return self._core.io.query_struct(f'CALibration:BASE:LATest:SPECific? {param}', self.__class__.GetStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Impedance:
	"""Impedance commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("impedance", core, parent)

	def set(self, impedance: enums.Impedance, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:BASE:AIN<nr>:ZBOX:IMPedance \n
		Snippet: driver.configure.base.audioInput.zbox.impedance.set(impedance = enums.Impedance.IHOL, audioInput = repcap.AudioInput.Default) \n
		Specifies the impedance that is configured at the impedance matching unit. \n
			:param impedance: IHOL | R50 | R150 | R300 | R600 IHOL In high / out low R50 | R150 | R300 | R600 50 Ω | 150 Ω | 300 Ω | 600 Ω
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.enum_scalar_to_str(impedance, enums.Impedance)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:BASE:AIN{audioInput_cmd_val}:ZBOX:IMPedance {param}')

	# noinspection PyTypeChecker
	def get(self, audioInput=repcap.AudioInput.Default) -> enums.Impedance:
		"""SCPI: CONFigure:BASE:AIN<nr>:ZBOX:IMPedance \n
		Snippet: value: enums.Impedance = driver.configure.base.audioInput.zbox.impedance.get(audioInput = repcap.AudioInput.Default) \n
		Specifies the impedance that is configured at the impedance matching unit. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: impedance: IHOL | R50 | R150 | R300 | R600 IHOL In high / out low R50 | R150 | R300 | R600 50 Ω | 150 Ω | 300 Ω | 600 Ω"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:BASE:AIN{audioInput_cmd_val}:ZBOX:IMPedance?')
		return Conversions.str_to_scalar_enum(response, enums.Impedance)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tx:
	"""Tx commands group definition. 8 total commands, 1 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tx", core, parent)

	@property
	def demod(self):
		"""demod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_demod'):
			from .Tx_.Demod import Demod
			self._demod = Demod(self._core, self._base)
		return self._demod

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.SearchRoutine:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MODE \n
		Snippet: value: enums.SearchRoutine = driver.configure.afRf.measurement.searchRoutines.tx.get_mode() \n
		No command help available \n
			:return: search_routine: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.SearchRoutine)

	def set_mode(self, search_routine: enums.SearchRoutine) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MODE \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.set_mode(search_routine = enums.SearchRoutine.RIFBandwidth) \n
		No command help available \n
			:param search_routine: No help available
		"""
		param = Conversions.enum_scalar_to_str(search_routine, enums.SearchRoutine)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MODE {param}')

	def get_se_time(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:SETime \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tx.get_se_time() \n
		No command help available \n
			:return: setting_time: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:SETime?')
		return Conversions.str_to_float(response)

	def set_se_time(self, setting_time: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:SETime \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.set_se_time(setting_time = 1.0) \n
		No command help available \n
			:param setting_time: No help available
		"""
		param = Conversions.decimal_value_to_str(setting_time)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:SETime {param}')

	def get_mlevel(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MLEVel \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tx.get_mlevel() \n
		No command help available \n
			:return: max_level: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MLEVel?')
		return Conversions.str_to_float(response)

	def set_mlevel(self, max_level: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MLEVel \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.set_mlevel(max_level = 1.0) \n
		No command help available \n
			:param max_level: No help available
		"""
		param = Conversions.decimal_value_to_str(max_level)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:MLEVel {param}')

	# noinspection PyTypeChecker
	def get_af_source(self) -> enums.TxAfSource:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:AFSource \n
		Snippet: value: enums.TxAfSource = driver.configure.afRf.measurement.searchRoutines.tx.get_af_source() \n
		No command help available \n
			:return: af_source: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:AFSource?')
		return Conversions.str_to_scalar_enum(response, enums.TxAfSource)

	def set_af_source(self, af_source: enums.TxAfSource) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:AFSource \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.set_af_source(af_source = enums.TxAfSource.AF1O) \n
		No command help available \n
			:param af_source: No help available
		"""
		param = Conversions.enum_scalar_to_str(af_source, enums.TxAfSource)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:AFSource {param}')

	def get_rf_deviation(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RFDeviation \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tx.get_rf_deviation() \n
		No command help available \n
			:return: rated_freq_dev: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RFDeviation?')
		return Conversions.str_to_float(response)

	def set_rf_deviation(self, rated_freq_dev: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RFDeviation \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.set_rf_deviation(rated_freq_dev = 1.0) \n
		No command help available \n
			:param rated_freq_dev: No help available
		"""
		param = Conversions.decimal_value_to_str(rated_freq_dev)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RFDeviation {param}')

	def get_rp_deviation(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RPDeviation \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tx.get_rp_deviation() \n
		No command help available \n
			:return: rated_phase_dev: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RPDeviation?')
		return Conversions.str_to_float(response)

	def set_rp_deviation(self, rated_phase_dev: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RPDeviation \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.set_rp_deviation(rated_phase_dev = 1.0) \n
		No command help available \n
			:param rated_phase_dev: No help available
		"""
		param = Conversions.decimal_value_to_str(rated_phase_dev)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RPDeviation {param}')

	def get_rm_depth(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RMDepth \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tx.get_rm_depth() \n
		No command help available \n
			:return: rated_mod_depth: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RMDepth?')
		return Conversions.str_to_float(response)

	def set_rm_depth(self, rated_mod_depth: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RMDepth \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.set_rm_depth(rated_mod_depth = 1.0) \n
		No command help available \n
			:param rated_mod_depth: No help available
		"""
		param = Conversions.decimal_value_to_str(rated_mod_depth)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:RMDepth {param}')

	def clone(self) -> 'Tx':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tx(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dpmr:
	"""Dpmr commands group definition. 13 total commands, 1 Sub-groups, 11 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dpmr", core, parent)

	@property
	def ccode(self):
		"""ccode commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ccode'):
			from .Dpmr_.Ccode import Ccode
			self._ccode = Ccode(self._core, self._base)
		return self._ccode

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.NxdnPatternB:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:PATTern \n
		Snippet: value: enums.NxdnPatternB = driver.source.afRf.generator.dpmr.get_pattern() \n
		No command help available \n
			:return: pattern: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.NxdnPatternB)

	def set_pattern(self, pattern: enums.NxdnPatternB) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:PATTern \n
		Snippet: driver.source.afRf.generator.dpmr.set_pattern(pattern = enums.NxdnPatternB.CUST) \n
		No command help available \n
			:param pattern: No help available
		"""
		param = Conversions.enum_scalar_to_str(pattern, enums.NxdnPatternB)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:PATTern {param}')

	def get_svalue(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:SVALue \n
		Snippet: value: str = driver.source.afRf.generator.dpmr.get_svalue() \n
		No command help available \n
			:return: svalue: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:SVALue?')
		return trim_str_response(response)

	def set_svalue(self, svalue: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:SVALue \n
		Snippet: driver.source.afRf.generator.dpmr.set_svalue(svalue = r1) \n
		No command help available \n
			:param svalue: No help available
		"""
		param = Conversions.value_to_str(svalue)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:SVALue {param}')

	def get_sid(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:SID \n
		Snippet: value: str = driver.source.afRf.generator.dpmr.get_sid() \n
		No command help available \n
			:return: sid: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:SID?')
		return trim_str_response(response)

	def set_sid(self, sid: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:SID \n
		Snippet: driver.source.afRf.generator.dpmr.set_sid(sid = '1') \n
		No command help available \n
			:param sid: No help available
		"""
		param = Conversions.value_to_quoted_str(sid)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:SID {param}')

	def get_did(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:DID \n
		Snippet: value: str = driver.source.afRf.generator.dpmr.get_did() \n
		No command help available \n
			:return: did: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:DID?')
		return trim_str_response(response)

	def set_did(self, did: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:DID \n
		Snippet: driver.source.afRf.generator.dpmr.set_did(did = '1') \n
		No command help available \n
			:param did: No help available
		"""
		param = Conversions.value_to_quoted_str(did)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:DID {param}')

	def get_pt_peer(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:PTPeer \n
		Snippet: value: bool = driver.source.afRf.generator.dpmr.get_pt_peer() \n
		No command help available \n
			:return: emergency: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:PTPeer?')
		return Conversions.str_to_bool(response)

	def set_pt_peer(self, emergency: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:PTPeer \n
		Snippet: driver.source.afRf.generator.dpmr.set_pt_peer(emergency = False) \n
		No command help available \n
			:param emergency: No help available
		"""
		param = Conversions.bool_to_str(emergency)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:PTPeer {param}')

	def get_emergency(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:EMERgency \n
		Snippet: value: bool = driver.source.afRf.generator.dpmr.get_emergency() \n
		No command help available \n
			:return: emergency: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:EMERgency?')
		return Conversions.str_to_bool(response)

	def set_emergency(self, emergency: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:EMERgency \n
		Snippet: driver.source.afRf.generator.dpmr.set_emergency(emergency = False) \n
		No command help available \n
			:param emergency: No help available
		"""
		param = Conversions.bool_to_str(emergency)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:EMERgency {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FskMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:MODE \n
		Snippet: value: enums.FskMode = driver.source.afRf.generator.dpmr.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DPMR:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FskMode)

	def get_standard_dev(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:SDEViation \n
		Snippet: value: List[float] = driver.source.afRf.generator.dpmr.get_standard_dev() \n
		No command help available \n
			:return: sdeviation: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:SDEViation?')
		return response

	def get_symbol_rate(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:SRATe \n
		Snippet: value: float = driver.source.afRf.generator.dpmr.get_symbol_rate() \n
		No command help available \n
			:return: srate: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DPMR:SRATe?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_filter_py(self) -> enums.PulseShapingFilter:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:FILTer \n
		Snippet: value: enums.PulseShapingFilter = driver.source.afRf.generator.dpmr.get_filter_py() \n
		No command help available \n
			:return: filter_py: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DPMR:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.PulseShapingFilter)

	def get_ro_factor(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:ROFactor \n
		Snippet: value: float = driver.source.afRf.generator.dpmr.get_ro_factor() \n
		No command help available \n
			:return: ro_factor: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DPMR:ROFactor?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Dpmr':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dpmr(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Update:
	"""Update commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("update", core, parent)

	def set(self) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FREQuency:DELTa:UPDate \n
		Snippet: driver.configure.afRf.measurement.spdif.frequency.delta.update.set() \n
		No command help available \n
		"""
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SIN:FREQuency:DELTa:UPDate')

	def set_with_opc(self) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FREQuency:DELTa:UPDate \n
		Snippet: driver.configure.afRf.measurement.spdif.frequency.delta.update.set_with_opc() \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'CONFigure:AFRF:MEASurement<Instance>:SIN:FREQuency:DELTa:UPDate')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Capture:
	"""Capture commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("capture", core, parent)

	def set(self, capt_pre_trig: int, capt_post_trig: int = None, standard: enums.Standard = None) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:CAPTure \n
		Snippet: driver.configure.vse.measurement.iqRecorder.capture.set(capt_pre_trig = 1, capt_post_trig = 1, standard = enums.Standard.CUSTom) \n
		Sets or queries the number of samples to be received before IQ recording is started ('Pre Trigger') and after which IQ
		recording is stopped ('Post Trigger') . \n
			:param capt_pre_trig: Range: 1 Samples to 4194303
			:param capt_post_trig: Range: 1 Samples to 4194303
			:param standard: DMR | NXDN | P25 | TETRa | LTE | UDEFined
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('capt_pre_trig', capt_pre_trig, DataType.Integer), ArgSingle('capt_post_trig', capt_post_trig, DataType.Integer, True), ArgSingle('standard', standard, DataType.Enum, True))
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:CAPTure {param}'.rstrip())

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Capt_Pre_Trig: int: Range: 1 Samples to 4194303
			- Capt_Post_Trig: int: Range: 1 Samples to 4194303"""
		__meta_args_list = [
			ArgStruct.scalar_int('Capt_Pre_Trig'),
			ArgStruct.scalar_int('Capt_Post_Trig')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Capt_Pre_Trig: int = None
			self.Capt_Post_Trig: int = None

	def get(self) -> GetStruct:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:CAPTure \n
		Snippet: value: GetStruct = driver.configure.vse.measurement.iqRecorder.capture.get() \n
		Sets or queries the number of samples to be received before IQ recording is started ('Pre Trigger') and after which IQ
		recording is stopped ('Post Trigger') . \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:CAPTure?', self.__class__.GetStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Samples:
	"""Samples commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("samples", core, parent)

	# noinspection PyTypeChecker
	class RangeStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Range_Py: enums.ArbSamplesRange: FULL | SUB FULL Process all samples SUB Process a subrange according to Start and Stop
			- Start: int: Start of the subrange (always first sample, labeled zero) Range: 0 (fixed value)
			- Stop: int: End of the subrange Range: 16 to samples in ARB file - 1"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Range_Py', enums.ArbSamplesRange),
			ArgStruct.scalar_int('Start'),
			ArgStruct.scalar_int('Stop')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Range_Py: enums.ArbSamplesRange = None
			self.Start: int = None
			self.Stop: int = None

	# noinspection PyTypeChecker
	def get_range(self) -> RangeStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:SAMPles:RANGe \n
		Snippet: value: RangeStruct = driver.source.afRf.generator.arb.samples.get_range() \n
		Selects whether all samples or a subrange of samples is processed. \n
			:return: structure: for return value, see the help for RangeStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:ARB:SAMPles:RANGe?', self.__class__.RangeStruct())

	def set_range(self, value: RangeStruct) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:SAMPles:RANGe \n
		Snippet: driver.source.afRf.generator.arb.samples.set_range(value = RangeStruct()) \n
		Selects whether all samples or a subrange of samples is processed. \n
			:param value: see the help for RangeStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce:AFRF:GENerator<Instance>:ARB:SAMPles:RANGe', value)

	def get_value(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:SAMPles \n
		Snippet: value: float = driver.source.afRf.generator.arb.samples.get_value() \n
		Queries the number of samples in the loaded ARB file. \n
			:return: samples: Range: 0 to 268173312
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:SAMPles?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FirmwareUpdate:
	"""FirmwareUpdate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("firmwareUpdate", core, parent)

	def get_info(self) -> str:
		"""SCPI: SENSe:FWUPdate:INFO \n
		Snippet: value: str = driver.sense.firmwareUpdate.get_info() \n
		No command help available \n
			:return: info: No help available
		"""
		response = self._core.io.query_str('SENSe:FWUPdate:INFO?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scal:
	"""Scal commands group definition. 8 total commands, 3 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("scal", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .Scal_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def userDefined(self):
		"""userDefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_userDefined'):
			from .Scal_.UserDefined import UserDefined
			self._userDefined = UserDefined(self._core, self._base)
		return self._userDefined

	@property
	def ttime(self):
		"""ttime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttime'):
			from .Scal_.Ttime import Ttime
			self._ttime = Ttime(self._core, self._base)
		return self._ttime

	def get_sequence(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SEQuence \n
		Snippet: value: str = driver.source.afRf.generator.dialing.scal.get_sequence() \n
		Specifies the SELCAL code (without the hyphen) . \n
			:return: scal_sequence: String with four letters The allowed letters are A to H, J to M and P to S. A letter must not appear twice. The first two letters and the last two letters must be ordered alphabetically.
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SEQuence?')
		return trim_str_response(response)

	def set_sequence(self, scal_sequence: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SEQuence \n
		Snippet: driver.source.afRf.generator.dialing.scal.set_sequence(scal_sequence = '1') \n
		Specifies the SELCAL code (without the hyphen) . \n
			:param scal_sequence: String with four letters The allowed letters are A to H, J to M and P to S. A letter must not appear twice. The first two letters and the last two letters must be ordered alphabetically.
		"""
		param = Conversions.value_to_quoted_str(scal_sequence)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SEQuence {param}')

	def get_srepeat(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SREPeat \n
		Snippet: value: int = driver.source.afRf.generator.dialing.scal.get_srepeat() \n
		Defines how often a SELCAL sequence (two dual tones) is repeated. \n
			:return: sequence_repeat: Range: 1 to 100
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SREPeat?')
		return Conversions.str_to_int(response)

	def set_srepeat(self, sequence_repeat: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SREPeat \n
		Snippet: driver.source.afRf.generator.dialing.scal.set_srepeat(sequence_repeat = 1) \n
		Defines how often a SELCAL sequence (two dual tones) is repeated. \n
			:param sequence_repeat: Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(sequence_repeat)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SREPeat {param}')

	def get_spause(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SPAuse \n
		Snippet: value: float = driver.source.afRf.generator.dialing.scal.get_spause() \n
		Defines the duration of a pause between two repetitions of a SELCAL sequence. \n
			:return: sequence_pause: Range: 0.1 s to 10 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SPAuse?')
		return Conversions.str_to_float(response)

	def set_spause(self, sequence_pause: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SPAuse \n
		Snippet: driver.source.afRf.generator.dialing.scal.set_spause(sequence_pause = 1.0) \n
		Defines the duration of a pause between two repetitions of a SELCAL sequence. \n
			:param sequence_pause: Range: 0.1 s to 10 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(sequence_pause)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:SPAuse {param}')

	def get_tpause(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TPAuse \n
		Snippet: value: float = driver.source.afRf.generator.dialing.scal.get_tpause() \n
		Defines the duration of the pause between the two dual tones of a SELCAL sequence. \n
			:return: tpause: Range: 0.1 s to 3 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TPAuse?')
		return Conversions.str_to_float(response)

	def set_tpause(self, tpause: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TPAuse \n
		Snippet: driver.source.afRf.generator.dialing.scal.set_tpause(tpause = 1.0) \n
		Defines the duration of the pause between the two dual tones of a SELCAL sequence. \n
			:param tpause: Range: 0.1 s to 3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(tpause)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TPAuse {param}')

	def clone(self) -> 'Scal':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Scal(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	@property
	def bandpass(self):
		"""bandpass commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bandpass'):
			from .FilterPy_.Bandpass import Bandpass
			self._bandpass = Bandpass(self._core, self._base)
		return self._bandpass

	@property
	def gauss(self):
		"""gauss commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gauss'):
			from .FilterPy_.Gauss import Gauss
			self._gauss = Gauss(self._core, self._base)
		return self._gauss

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.RbwFilterType:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FILTer:TYPE \n
		Snippet: value: enums.RbwFilterType = driver.configure.gprfMeasurement.iqRecorder.filterPy.get_type_py() \n
		Selects the IF filter type. \n
			:return: filter_type: BANDpass | GAUSs BANDpass Bandpass filter with selectable bandwidth GAUSs Gaussian filter with selectable bandwidth
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FILTer:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.RbwFilterType)

	def set_type_py(self, filter_type: enums.RbwFilterType) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FILTer:TYPE \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.filterPy.set_type_py(filter_type = enums.RbwFilterType.BANDpass) \n
		Selects the IF filter type. \n
			:param filter_type: BANDpass | GAUSs BANDpass Bandpass filter with selectable bandwidth GAUSs Gaussian filter with selectable bandwidth
		"""
		param = Conversions.enum_scalar_to_str(filter_type, enums.RbwFilterType)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FILTer:TYPE {param}')

	def clone(self) -> 'FilterPy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Audio_Dev_Left: float: Peak frequency deviation due to the left audio channel Unit: Hz
			- Audio_Dev_Right: float: Peak frequency deviation due to the right audio channel Unit: Hz
			- Pilot_Deviation: float: Peak frequency deviation due to the pilot tone Unit: Hz
			- Pilot_Freq_Error: float: Frequency error of the pilot tone Unit: Hz
			- Rds_Deviation: float: Peak frequency deviation due to the signal in the RDS band Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Audio_Dev_Left'),
			ArgStruct.scalar_float('Audio_Dev_Right'),
			ArgStruct.scalar_float('Pilot_Deviation'),
			ArgStruct.scalar_float('Pilot_Freq_Error'),
			ArgStruct.scalar_float('Rds_Deviation')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Audio_Dev_Left: float = None
			self.Audio_Dev_Right: float = None
			self.Pilot_Deviation: float = None
			self.Pilot_Freq_Error: float = None
			self.Rds_Deviation: float = None

	def calculate(self) -> CalculateStruct:
		"""SCPI: CALCulate:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FMSTereo:CURRent \n
		Snippet: value: CalculateStruct = driver.afRf.measurement.multiEval.demodulation.fmStereo.current.calculate() \n
		Queries the demodulation results for the individual components of an FM stereo signal. CALCulate commands return error
		indicators instead of measurement values. \n
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		return self._core.io.query_struct(f'CALCulate:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FMSTereo:CURRent?', self.__class__.CalculateStruct())

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Audio_Dev_Left: float: Peak frequency deviation due to the left audio channel Unit: Hz
			- Audio_Dev_Right: float: Peak frequency deviation due to the right audio channel Unit: Hz
			- Pilot_Deviation: float: Peak frequency deviation due to the pilot tone Unit: Hz
			- Pilot_Freq_Error: float: Frequency error of the pilot tone Unit: Hz
			- Rds_Deviation: float: Peak frequency deviation due to the signal in the RDS band Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Audio_Dev_Left'),
			ArgStruct.scalar_float('Audio_Dev_Right'),
			ArgStruct.scalar_float('Pilot_Deviation'),
			ArgStruct.scalar_float('Pilot_Freq_Error'),
			ArgStruct.scalar_float('Rds_Deviation')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Audio_Dev_Left: float = None
			self.Audio_Dev_Right: float = None
			self.Pilot_Deviation: float = None
			self.Pilot_Freq_Error: float = None
			self.Rds_Deviation: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FMSTereo:CURRent \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.demodulation.fmStereo.current.fetch() \n
		Queries the demodulation results for the individual components of an FM stereo signal. CALCulate commands return error
		indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FMSTereo:CURRent?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FMSTereo:CURRent \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.demodulation.fmStereo.current.read() \n
		Queries the demodulation results for the individual components of an FM stereo signal. CALCulate commands return error
		indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FMSTereo:CURRent?', self.__class__.ResultData())



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Types import DataType
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Attribute:
	"""Attribute commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("attribute", core, parent)

	def set(self, path_name: str, attributes: str) -> None:
		"""SCPI: MMEMory:ATTRibute \n
		Snippet: driver.massMemory.attribute.set(path_name = '1', attributes = '1') \n
		Sets or removes attributes for files and directories, or queries the attributes. \n
			:param path_name: No help available
			:param attributes: Attribute actions, separated by a blank + before an attribute: Sets the attribute. - before an attribute: Deletes the attribute. Possible attributes: R: read-only file A: archive file S: system file H: hidden file
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('path_name', path_name, DataType.String), ArgSingle('attributes', attributes, DataType.String))
		self._core.io.write(f'MMEMory:ATTRibute {param}'.rstrip())

	def get(self, path_name: str) -> List[str]:
		"""SCPI: MMEMory:ATTRibute \n
		Snippet: value: List[str] = driver.massMemory.attribute.get(path_name = '1') \n
		Sets or removes attributes for files and directories, or queries the attributes. \n
			:param path_name: No help available
			:return: file_entry: No help available"""
		param = Conversions.value_to_quoted_str(path_name)
		response = self._core.io.query_str(f'MMEMory:ATTRibute? {param}')
		return Conversions.str_to_str_list(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Demodulation:
	"""Demodulation commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("demodulation", core, parent)

	# noinspection PyTypeChecker
	def get_tmode(self) -> enums.DigitalToneMode:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:DEModulation:TMODe \n
		Snippet: value: enums.DigitalToneMode = driver.configure.afRf.measurement.multiEval.demodulation.get_tmode() \n
		No command help available \n
			:return: tone_mode: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:DEModulation:TMODe?')
		return Conversions.str_to_scalar_enum(response, enums.DigitalToneMode)

	def set_tmode(self, tone_mode: enums.DigitalToneMode) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:DEModulation:TMODe \n
		Snippet: driver.configure.afRf.measurement.multiEval.demodulation.set_tmode(tone_mode = enums.DigitalToneMode.DCS) \n
		No command help available \n
			:param tone_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(tone_mode, enums.DigitalToneMode)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:DEModulation:TMODe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType
from .....Internal.Utilities import trim_str_response
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reliability:
	"""Reliability commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("reliability", core, parent)

	def get(self, details: str = None) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RELiability \n
		Snippet: value: str = driver.source.afRf.generator.reliability.get(details = '1') \n
		Queries whether the generator has detected an error or not. If you have problems to generate a signal, use this command
		for troubleshooting. The returned parameters comprise a reliability indicator value and optionally, an error reason. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:param details: To return an error reason in addition to the reliability indicator value, append 'Details' to the query: SOUR:AFRF:GEN:REL? 'DETails'
			:return: reliability_msg: String indicating the error reason If there is no error (reliability value = 0) , the string is empty. The parameter is only returned if parameter Details = 'DETails'."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('details', details, DataType.String, True))
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'SOURce:AFRF:GENerator<Instance>:RELiability? {param}'.rstrip(), suppressed)
		return trim_str_response(response)

	# noinspection PyTypeChecker
	class AllStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Reliability_Msg: str: String indicating the error reason If there is no error (reliability value = 0) , the string is empty.
			- Reliability_Add_Info: str: String providing additional information for an error If there is no error (reliability value = 0) , the string is empty."""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_str('Reliability_Msg'),
			ArgStruct.scalar_str('Reliability_Add_Info')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Reliability_Msg: str = None
			self.Reliability_Add_Info: str = None

	def get_all(self) -> AllStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RELiability:ALL \n
		Snippet: value: AllStruct = driver.source.afRf.generator.reliability.get_all() \n
		Queries whether the generator has detected an error or not. If you have problems to generate a signal, use this command
		for troubleshooting. The returned parameters comprise a reliability indicator value, an error reason and an additional
		information string. \n
			:return: structure: for return value, see the help for AllStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:RELiability:ALL?', self.__class__.AllStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spectrum:
	"""Spectrum commands group definition. 32 total commands, 6 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spectrum", core, parent)

	@property
	def tgenerator(self):
		"""tgenerator commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tgenerator'):
			from .Spectrum_.Tgenerator import Tgenerator
			self._tgenerator = Tgenerator(self._core, self._base)
		return self._tgenerator

	@property
	def zeroSpan(self):
		"""zeroSpan commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_zeroSpan'):
			from .Spectrum_.ZeroSpan import ZeroSpan
			self._zeroSpan = ZeroSpan(self._core, self._base)
		return self._zeroSpan

	@property
	def frequency(self):
		"""frequency commands group. 2 Sub-classes, 4 commands."""
		if not hasattr(self, '_frequency'):
			from .Spectrum_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def freqSweep(self):
		"""freqSweep commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqSweep'):
			from .Spectrum_.FreqSweep import FreqSweep
			self._freqSweep = FreqSweep(self._core, self._base)
		return self._freqSweep

	@property
	def vswr(self):
		"""vswr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vswr'):
			from .Spectrum_.Vswr import Vswr
			self._vswr = Vswr(self._core, self._base)
		return self._vswr

	@property
	def marker(self):
		"""marker commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_marker'):
			from .Spectrum_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	# noinspection PyTypeChecker
	def get_amode(self) -> enums.AveragingMode:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:AMODe \n
		Snippet: value: enums.AveragingMode = driver.configure.gprfMeasurement.spectrum.get_amode() \n
		Defines how the average trace is derived from the current trace. \n
			:return: averaging_mode: LINear | LOGarithmic LINear Averaging of the linear powers LOGarithmic Averaging of the dBm values
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:AMODe?')
		return Conversions.str_to_scalar_enum(response, enums.AveragingMode)

	def set_amode(self, averaging_mode: enums.AveragingMode) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:AMODe \n
		Snippet: driver.configure.gprfMeasurement.spectrum.set_amode(averaging_mode = enums.AveragingMode.LINear) \n
		Defines how the average trace is derived from the current trace. \n
			:param averaging_mode: LINear | LOGarithmic LINear Averaging of the linear powers LOGarithmic Averaging of the dBm values
		"""
		param = Conversions.enum_scalar_to_str(averaging_mode, enums.AveragingMode)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:AMODe {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.gprfMeasurement.spectrum.get_repetition() \n
		Selects whether the measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:REPetition \n
		Snippet: driver.configure.gprfMeasurement.spectrum.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:REPetition {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:RCOupling \n
		Snippet: value: bool = driver.configure.gprfMeasurement.spectrum.get_rcoupling() \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:return: repetition_coupl: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupl: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:RCOupling \n
		Snippet: driver.configure.gprfMeasurement.spectrum.set_rcoupling(repetition_coupl = False) \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:param repetition_coupl: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupl)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:RCOupling {param}')

	def get_timeout(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TOUT \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.get_timeout() \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:return: tcd_timeout: Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, tcd_timeout: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TOUT \n
		Snippet: driver.configure.gprfMeasurement.spectrum.set_timeout(tcd_timeout = 1.0) \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:param tcd_timeout: Unit: s
		"""
		param = Conversions.decimal_value_to_str(tcd_timeout)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TOUT {param}')

	def get_scount(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:SCOunt \n
		Snippet: value: int = driver.configure.gprfMeasurement.spectrum.get_scount() \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval covers the frequency span
		defined for the 'Frequency Sweep' mode, or the sweep time defined for the 'Zero Span' mode. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:SCOunt \n
		Snippet: driver.configure.gprfMeasurement.spectrum.set_scount(statistic_count = 1) \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval covers the frequency span
		defined for the 'Frequency Sweep' mode, or the sweep time defined for the 'Zero Span' mode. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:SCOunt {param}')

	def clone(self) -> 'Spectrum':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Spectrum(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Instrument:
	"""Instrument commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("instrument", core, parent)

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_select'):
			from .Instrument_.Select import Select
			self._select = Select(self._core, self._base)
		return self._select

	def get_nselect(self) -> int:
		"""SCPI: INSTrument:NSELect \n
		Snippet: value: int = driver.instrument.get_nselect() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('INSTrument:NSELect?')
		return Conversions.str_to_int(response)

	def set_nselect(self, arg_0: int) -> None:
		"""SCPI: INSTrument:NSELect \n
		Snippet: driver.instrument.set_nselect(arg_0 = 1) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'INSTrument:NSELect {param}')

	def clone(self) -> 'Instrument':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Instrument(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRate:
	"""SymbolRate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("symbolRate", core, parent)

	def fetch(self) -> float:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:IQRecorder:SRATe \n
		Snippet: value: float = driver.gprfMeasurement.iqRecorder.symbolRate.fetch() \n
		Returns the maximum sample rate, resulting from the filter settings. \n
			:return: sample_rate: Unit: Hz"""
		response = self._core.io.query_str(f'FETCh:GPRF:MEASurement<Instance>:IQRecorder:SRATe?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Af:
	"""Af commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("af", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:AF:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.interferer.af.get_enable() \n
		Enables or disables a single tone. If the tone is disabled, the interferer is unmodulated, even if a modulation mode has
		been configured. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:AF:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:AF:ENABle \n
		Snippet: driver.source.afRf.generator.interferer.af.set_enable(enable = False) \n
		Enables or disables a single tone. If the tone is disabled, the interferer is unmodulated, even if a modulation mode has
		been configured. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:AF:ENABle {param}')

	def get_frequency(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:AF:FREQuency \n
		Snippet: value: float = driver.source.afRf.generator.interferer.af.get_frequency() \n
		Configures the frequency of a single tone, that can be added to the interferer. \n
			:return: frequency: Range: 0 Hz to 21 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:AF:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:AF:FREQuency \n
		Snippet: driver.source.afRf.generator.interferer.af.set_frequency(frequency = 1.0) \n
		Configures the frequency of a single tone, that can be added to the interferer. \n
			:param frequency: Range: 0 Hz to 21 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:AF:FREQuency {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nrt:
	"""Nrt commands group definition. 30 total commands, 3 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nrt", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Nrt_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def forward(self):
		"""forward commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_forward'):
			from .Nrt_.Forward import Forward
			self._forward = Forward(self._core, self._base)
		return self._forward

	@property
	def reverse(self):
		"""reverse commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_reverse'):
			from .Nrt_.Reverse import Reverse
			self._reverse = Reverse(self._core, self._base)
		return self._reverse

	def initiate(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:NRT \n
		Snippet: driver.gprfMeasurement.nrt.initiate() \n
		Starts or continues the NRT-Z measurement. \n
		"""
		self._core.io.write(f'INITiate:GPRF:MEASurement<Instance>:NRT')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:NRT \n
		Snippet: driver.gprfMeasurement.nrt.initiate_with_opc() \n
		Starts or continues the NRT-Z measurement. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:NRT')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:NRT \n
		Snippet: driver.gprfMeasurement.nrt.stop() \n
		Pauses the NRT-Z measurement. \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:NRT')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:NRT \n
		Snippet: driver.gprfMeasurement.nrt.stop_with_opc() \n
		Pauses the NRT-Z measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:NRT')

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:NRT \n
		Snippet: driver.gprfMeasurement.nrt.abort() \n
		Stops the NRT-Z measurement. \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:NRT')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:NRT \n
		Snippet: driver.gprfMeasurement.nrt.abort_with_opc() \n
		Stops the NRT-Z measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:NRT')

	def get_idn(self) -> str:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:NRT:IDN \n
		Snippet: value: str = driver.gprfMeasurement.nrt.get_idn() \n
		Queries the identification string of the connected external power sensor. \n
			:return: idn: String parameter
		"""
		response = self._core.io.query_str('FETCh:GPRF:MEASurement<Instance>:NRT:IDN?')
		return trim_str_response(response)

	def clone(self) -> 'Nrt':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nrt(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dcs:
	"""Dcs commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dcs", core, parent)

	# noinspection PyTypeChecker
	class FskDeviationStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower limit Range: -10 kHz to 0 Hz, Unit: Hz
			- Upper: float: Upper limit Range: 0 Hz to 10 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_fsk_deviation(self) -> FskDeviationStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:FSKDeviation \n
		Snippet: value: FskDeviationStruct = driver.configure.afRf.measurement.multiEval.limit.tones.dcs.get_fsk_deviation() \n
		Configures limits for the FSK deviation measured for a DCS signal. \n
			:return: structure: for return value, see the help for FskDeviationStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:FSKDeviation?', self.__class__.FskDeviationStruct())

	def set_fsk_deviation(self, value: FskDeviationStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:FSKDeviation \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.dcs.set_fsk_deviation(value = FskDeviationStruct()) \n
		Configures limits for the FSK deviation measured for a DCS signal. \n
			:param value: see the help for FskDeviationStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:FSKDeviation', value)

	# noinspection PyTypeChecker
	class TocLengthStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower limit Range: 0 s to 0.15 s, Unit: s
			- Upper: float: Upper limit Range: 0.15 s to 1 s, Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_toc_length(self) -> TocLengthStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOCLength \n
		Snippet: value: TocLengthStruct = driver.configure.afRf.measurement.multiEval.limit.tones.dcs.get_toc_length() \n
		Configures limits for the duration of DCS turn-off code transmissions. \n
			:return: structure: for return value, see the help for TocLengthStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOCLength?', self.__class__.TocLengthStruct())

	def set_toc_length(self, value: TocLengthStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOCLength \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.dcs.set_toc_length(value = TocLengthStruct()) \n
		Configures limits for the duration of DCS turn-off code transmissions. \n
			:param value: see the help for TocLengthStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOCLength', value)

	# noinspection PyTypeChecker
	class TofDeviationStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: No parameter help available
			- Upper: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_tof_deviation(self) -> TofDeviationStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOFDeviation \n
		Snippet: value: TofDeviationStruct = driver.configure.afRf.measurement.multiEval.limit.tones.dcs.get_tof_deviation() \n
		No command help available \n
			:return: structure: for return value, see the help for TofDeviationStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOFDeviation?', self.__class__.TofDeviationStruct())

	def set_tof_deviation(self, value: TofDeviationStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOFDeviation \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.dcs.set_tof_deviation(value = TofDeviationStruct()) \n
		No command help available \n
			:param value: see the help for TofDeviationStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DCS:TOFDeviation', value)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nlevel:
	"""Nlevel commands group definition. 4 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nlevel", core, parent)

	@property
	def trace(self):
		"""trace commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_trace'):
			from .Nlevel_.Trace import Trace
			self._trace = Trace(self._core, self._base)
		return self._trace

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Lower_Noise_Level: float: No parameter help available
			- Higher_Noise_Level: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Lower_Noise_Level'),
			ArgStruct.scalar_float('Higher_Noise_Level')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Lower_Noise_Level: float = None
			self.Higher_Noise_Level: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:NLEVel \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rifBandwidth.nlevel.fetch() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:NLEVel?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:NLEVel \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rifBandwidth.nlevel.read() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:NLEVel?', self.__class__.ResultData())

	def clone(self) -> 'Nlevel':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nlevel(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	def set(self, frequency: float, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:FREQuency \n
		Snippet: driver.source.afRf.generator.internalGenerator.frequency.set(frequency = 1.0, internalGen = repcap.InternalGen.Default) \n
		Configures the frequency of a single tone or square signal, generated by an internal audio generator.
		The maximum frequency for square signals is 4000 Hz. \n
			:param frequency: Range: 0 Hz to 21 kHz, Unit: Hz
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.decimal_value_to_str(frequency)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:FREQuency {param}')

	def get(self, internalGen=repcap.InternalGen.Default) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:FREQuency \n
		Snippet: value: float = driver.source.afRf.generator.internalGenerator.frequency.get(internalGen = repcap.InternalGen.Default) \n
		Configures the frequency of a single tone or square signal, generated by an internal audio generator.
		The maximum frequency for square signals is 4000 Hz. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: frequency: Range: 0 Hz to 21 kHz, Unit: Hz"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:FREQuency?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dtmf:
	"""Dtmf commands group definition. 8 total commands, 2 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dtmf", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .Dtmf_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def userDefined(self):
		"""userDefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_userDefined'):
			from .Dtmf_.UserDefined import UserDefined
			self._userDefined = UserDefined(self._core, self._base)
		return self._userDefined

	def get_sequence(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SEQuence \n
		Snippet: value: str = driver.source.afRf.generator.dialing.dtmf.get_sequence() \n
		Specifies a digit sequence for the dialing mode DTMF. \n
			:return: dtm_fsequence: String with 1 to 42 digits The allowed digits are 0 to 9, A to D, * and # (with user-defined tone table also m) .
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SEQuence?')
		return trim_str_response(response)

	def set_sequence(self, dtm_fsequence: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SEQuence \n
		Snippet: driver.source.afRf.generator.dialing.dtmf.set_sequence(dtm_fsequence = '1') \n
		Specifies a digit sequence for the dialing mode DTMF. \n
			:param dtm_fsequence: String with 1 to 42 digits The allowed digits are 0 to 9, A to D, * and # (with user-defined tone table also m) .
		"""
		param = Conversions.value_to_quoted_str(dtm_fsequence)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SEQuence {param}')

	def get_srepeat(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SREPeat \n
		Snippet: value: int = driver.source.afRf.generator.dialing.dtmf.get_srepeat() \n
		Defines how often a DTMF sequence is repeated. \n
			:return: sequence_repeat: Range: 1 to 100
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SREPeat?')
		return Conversions.str_to_int(response)

	def set_srepeat(self, sequence_repeat: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SREPeat \n
		Snippet: driver.source.afRf.generator.dialing.dtmf.set_srepeat(sequence_repeat = 1) \n
		Defines how often a DTMF sequence is repeated. \n
			:param sequence_repeat: Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(sequence_repeat)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SREPeat {param}')

	def get_spause(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SPAuse \n
		Snippet: value: float = driver.source.afRf.generator.dialing.dtmf.get_spause() \n
		Defines the duration of a pause between two repetitions of a DTMF sequence. \n
			:return: sequence_pause: Range: 0 s to 10 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SPAuse?')
		return Conversions.str_to_float(response)

	def set_spause(self, sequence_pause: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SPAuse \n
		Snippet: driver.source.afRf.generator.dialing.dtmf.set_spause(sequence_pause = 1.0) \n
		Defines the duration of a pause between two repetitions of a DTMF sequence. \n
			:param sequence_pause: Range: 0 s to 10 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(sequence_pause)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:SPAuse {param}')

	def get_dtime(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DTIMe \n
		Snippet: value: float = driver.source.afRf.generator.dialing.dtmf.get_dtime() \n
		Defines the duration of a single digit of a DTMF sequence. \n
			:return: digit_time: Range: 0.02 s to 3 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DTIMe?')
		return Conversions.str_to_float(response)

	def set_dtime(self, digit_time: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DTIMe \n
		Snippet: driver.source.afRf.generator.dialing.dtmf.set_dtime(digit_time = 1.0) \n
		Defines the duration of a single digit of a DTMF sequence. \n
			:param digit_time: Range: 0.02 s to 3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(digit_time)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DTIMe {param}')

	def get_dpause(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DPAuse \n
		Snippet: value: float = driver.source.afRf.generator.dialing.dtmf.get_dpause() \n
		Defines the duration of the pause between two digits of a DTMF sequence. \n
			:return: digit_pause: Range: 0 s to 3 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DPAuse?')
		return Conversions.str_to_float(response)

	def set_dpause(self, digit_pause: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DPAuse \n
		Snippet: driver.source.afRf.generator.dialing.dtmf.set_dpause(digit_pause = 1.0) \n
		Defines the duration of the pause between two digits of a DTMF sequence. \n
			:param digit_pause: Range: 0 s to 3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(digit_pause)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:DTMF:DPAuse {param}')

	def clone(self) -> 'Dtmf':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dtmf(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Thd_Percent: enums.ResultStatus: Total harmonic distortion in percent Unit: %
			- Thd: float: Total harmonic distortion in dB Unit: dB
			- Thd_Plus_Noise: float: Total harmonic distortion and noise Unit: %
			- Sinad: enums.ResultStatus: Signal to noise and distortion Unit: dB
			- Snr: enums.ResultStatus: Signal-to-noise ratio S/N Unit: dB
			- Snr_Plus_Noise: float: (S+N) /N Unit: dB
			- Snr_Plus_Noinse_Plus_Dist: float: (S+N+D) /N Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_enum('Thd_Percent', enums.ResultStatus),
			ArgStruct.scalar_float('Thd'),
			ArgStruct.scalar_float('Thd_Plus_Noise'),
			ArgStruct.scalar_enum('Sinad', enums.ResultStatus),
			ArgStruct.scalar_enum('Snr', enums.ResultStatus),
			ArgStruct.scalar_float('Snr_Plus_Noise'),
			ArgStruct.scalar_float('Snr_Plus_Noinse_Plus_Dist')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Thd_Percent: enums.ResultStatus = None
			self.Thd: float = None
			self.Thd_Plus_Noise: float = None
			self.Sinad: enums.ResultStatus = None
			self.Snr: enums.ResultStatus = None
			self.Snr_Plus_Noise: float = None
			self.Snr_Plus_Noinse_Plus_Dist: float = None

	def calculate(self) -> CalculateStruct:
		"""SCPI: CALCulate:AFRF:MEASurement<Instance>:MEValuation:SQUality:DEMLeft:CURRent \n
		Snippet: value: CalculateStruct = driver.afRf.measurement.multiEval.signalQuality.demodLeft.current.calculate() \n
		Queries the signal quality results measured for the left demodulator channel. For FM stereo, these results are related to
		the left audio channel. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		return self._core.io.query_struct(f'CALCulate:AFRF:MEASurement<Instance>:MEValuation:SQUality:DEMLeft:CURRent?', self.__class__.CalculateStruct())

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Thd_Percent: float: Total harmonic distortion in percent Unit: %
			- Thd: float: Total harmonic distortion in dB Unit: dB
			- Thd_Plus_Noise: float: Total harmonic distortion and noise Unit: %
			- Sinad: float: Signal to noise and distortion Unit: dB
			- Snr: float: Signal-to-noise ratio S/N Unit: dB
			- Snr_Plus_Noise: float: (S+N) /N Unit: dB
			- Snr_Plus_Noinse_Plus_Dist: float: (S+N+D) /N Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Thd_Percent'),
			ArgStruct.scalar_float('Thd'),
			ArgStruct.scalar_float('Thd_Plus_Noise'),
			ArgStruct.scalar_float('Sinad'),
			ArgStruct.scalar_float('Snr'),
			ArgStruct.scalar_float('Snr_Plus_Noise'),
			ArgStruct.scalar_float('Snr_Plus_Noinse_Plus_Dist')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Thd_Percent: float = None
			self.Thd: float = None
			self.Thd_Plus_Noise: float = None
			self.Sinad: float = None
			self.Snr: float = None
			self.Snr_Plus_Noise: float = None
			self.Snr_Plus_Noinse_Plus_Dist: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:SQUality:DEMLeft:CURRent \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.signalQuality.demodLeft.current.fetch() \n
		Queries the signal quality results measured for the left demodulator channel. For FM stereo, these results are related to
		the left audio channel. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:SQUality:DEMLeft:CURRent?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:SQUality:DEMLeft:CURRent \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.signalQuality.demodLeft.current.read() \n
		Queries the signal quality results measured for the left demodulator channel. For FM stereo, these results are related to
		the left audio channel. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:SQUality:DEMLeft:CURRent?', self.__class__.ResultData())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelCall:
	"""SelCall commands group definition. 10 total commands, 2 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("selCall", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .SelCall_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def userDefined(self):
		"""userDefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_userDefined'):
			from .SelCall_.UserDefined import UserDefined
			self._userDefined = UserDefined(self._core, self._base)
		return self._userDefined

	# noinspection PyTypeChecker
	def get_standard(self) -> enums.SelCallStandard:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:STANdard \n
		Snippet: value: enums.SelCallStandard = driver.source.afRf.generator.dialing.selCall.get_standard() \n
		Selects the SelCall standard and thus the tone definition. \n
			:return: sel_call_standard: CCIR | EEA | EIA | ZVEI1 | ZVEI2 | ZVEI3 | DZVei | PZVei
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:STANdard?')
		return Conversions.str_to_scalar_enum(response, enums.SelCallStandard)

	def set_standard(self, sel_call_standard: enums.SelCallStandard) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:STANdard \n
		Snippet: driver.source.afRf.generator.dialing.selCall.set_standard(sel_call_standard = enums.SelCallStandard.CCIR) \n
		Selects the SelCall standard and thus the tone definition. \n
			:param sel_call_standard: CCIR | EEA | EIA | ZVEI1 | ZVEI2 | ZVEI3 | DZVei | PZVei
		"""
		param = Conversions.enum_scalar_to_str(sel_call_standard, enums.SelCallStandard)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:STANdard {param}')

	def get_sequence(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SEQuence \n
		Snippet: value: str = driver.source.afRf.generator.dialing.selCall.get_sequence() \n
		Specifies a digit sequence for the dialing mode SelCall. \n
			:return: sel_call_sequence: String with five digits - allowed digits are 0 to 9 and A to F If the user-defined tone definition is enabled, you can define 1 to 42 digits and also use the digit m.
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SEQuence?')
		return trim_str_response(response)

	def set_sequence(self, sel_call_sequence: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SEQuence \n
		Snippet: driver.source.afRf.generator.dialing.selCall.set_sequence(sel_call_sequence = '1') \n
		Specifies a digit sequence for the dialing mode SelCall. \n
			:param sel_call_sequence: String with five digits - allowed digits are 0 to 9 and A to F If the user-defined tone definition is enabled, you can define 1 to 42 digits and also use the digit m.
		"""
		param = Conversions.value_to_quoted_str(sel_call_sequence)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SEQuence {param}')

	def get_srepeat(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SREPeat \n
		Snippet: value: int = driver.source.afRf.generator.dialing.selCall.get_srepeat() \n
		Defines how often a SelCall sequence is repeated. \n
			:return: sequence_repeat: Range: 1 to 100
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SREPeat?')
		return Conversions.str_to_int(response)

	def set_srepeat(self, sequence_repeat: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SREPeat \n
		Snippet: driver.source.afRf.generator.dialing.selCall.set_srepeat(sequence_repeat = 1) \n
		Defines how often a SelCall sequence is repeated. \n
			:param sequence_repeat: Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(sequence_repeat)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SREPeat {param}')

	def get_spause(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SPAuse \n
		Snippet: value: float = driver.source.afRf.generator.dialing.selCall.get_spause() \n
		Defines the duration of a pause between two repetitions of a SelCall sequence. \n
			:return: sequence_pause: Range: 0 s to 10 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SPAuse?')
		return Conversions.str_to_float(response)

	def set_spause(self, sequence_pause: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SPAuse \n
		Snippet: driver.source.afRf.generator.dialing.selCall.set_spause(sequence_pause = 1.0) \n
		Defines the duration of a pause between two repetitions of a SelCall sequence. \n
			:param sequence_pause: Range: 0 s to 10 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(sequence_pause)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:SPAuse {param}')

	def get_dtime(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DTIMe \n
		Snippet: value: float = driver.source.afRf.generator.dialing.selCall.get_dtime() \n
		Defines the duration of a single digit of a SelCall sequence. \n
			:return: digit_time: Range: 0.02 s to 3 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DTIMe?')
		return Conversions.str_to_float(response)

	def set_dtime(self, digit_time: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DTIMe \n
		Snippet: driver.source.afRf.generator.dialing.selCall.set_dtime(digit_time = 1.0) \n
		Defines the duration of a single digit of a SelCall sequence. \n
			:param digit_time: Range: 0.02 s to 3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(digit_time)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DTIMe {param}')

	def get_dpause(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DPAuse \n
		Snippet: value: float = driver.source.afRf.generator.dialing.selCall.get_dpause() \n
		Defines the duration of the pause between two digits of a SelCall sequence. \n
			:return: digit_pause: Range: 0 s to 3 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DPAuse?')
		return Conversions.str_to_float(response)

	def set_dpause(self, digit_pause: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DPAuse \n
		Snippet: driver.source.afRf.generator.dialing.selCall.set_dpause(digit_pause = 1.0) \n
		Defines the duration of the pause between two digits of a SelCall sequence. \n
			:param digit_pause: Range: 0 s to 3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(digit_pause)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DPAuse {param}')

	def get_drepeat(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DREPeat \n
		Snippet: value: bool = driver.source.afRf.generator.dialing.selCall.get_drepeat() \n
		Enables or disables the usage of the repeat digit for the tone mode SelCall. \n
			:return: digit_repeat: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DREPeat?')
		return Conversions.str_to_bool(response)

	def set_drepeat(self, digit_repeat: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DREPeat \n
		Snippet: driver.source.afRf.generator.dialing.selCall.set_drepeat(digit_repeat = False) \n
		Enables or disables the usage of the repeat digit for the tone mode SelCall. \n
			:param digit_repeat: OFF | ON
		"""
		param = Conversions.bool_to_str(digit_repeat)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SELCall:DREPeat {param}')

	def clone(self) -> 'SelCall':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SelCall(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Slevel:
	"""Slevel commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("slevel", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Lower_Signal_Level: float: Range: -150 dBm to 150 dBm, Unit: dBm
			- Higher_Signal_Level: float: Range: -150 dBm to 150 dBm, Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Lower_Signal_Level'),
			ArgStruct.scalar_float('Higher_Signal_Level')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Lower_Signal_Level: float = None
			self.Higher_Signal_Level: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SLEVel \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rifBandwidth.slevel.fetch() \n
		Fetches the signal quality / noise level at the lower and higher frequency. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SLEVel?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SLEVel \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rifBandwidth.slevel.read() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SLEVel?', self.__class__.ResultData())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FreqSweep:
	"""FreqSweep commands group definition. 6 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("freqSweep", core, parent)

	@property
	def rbw(self):
		"""rbw commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rbw'):
			from .FreqSweep_.Rbw import Rbw
			self._rbw = Rbw(self._core, self._base)
		return self._rbw

	@property
	def vbw(self):
		"""vbw commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_vbw'):
			from .FreqSweep_.Vbw import Vbw
			self._vbw = Vbw(self._core, self._base)
		return self._vbw

	@property
	def swt(self):
		"""swt commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_swt'):
			from .FreqSweep_.Swt import Swt
			self._swt = Swt(self._core, self._base)
		return self._swt

	def clone(self) -> 'FreqSweep':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FreqSweep(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeviceFootprint:
	"""DeviceFootprint commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("deviceFootprint", core, parent)

	def set(self, path: str = None) -> None:
		"""SCPI: SYSTem:DFPRint \n
		Snippet: driver.system.deviceFootprint.set(path = '1') \n
		No command help available \n
			:param path: No help available
		"""
		param = ''
		if path:
			param = Conversions.value_to_quoted_str(path)
		self._core.io.write(f'SYSTem:DFPRint {param}'.strip())

	def get(self) -> bytes:
		"""SCPI: SYSTem:DFPRint \n
		Snippet: value: bytes = driver.system.deviceFootprint.get() \n
		No command help available \n
			:return: xml_device_footprint: No help available"""
		response = self._core.io.query_bin_block_ERROR(f'SYSTem:DFPRint?')
		return response
